#! /bin/sh
#
# MySQL tablak dump Debian System Maintainer felhasznaloval
#
# Eredeti valtozat: hornyak.alex@mimoza.hu
# Modositva: kovacs.zoltan@mimoza.hu 2005-05-13

EXIT_ERR="1"
USAGE="Usage: $0 [-c|--compress] database tablelist_file_pathname [backup_path|- [dump_user]]"

# Ezt a scriptet rootkent kell futtatni!
if [ ! $UID -eq 0 ]; then
    echo "Run as root, please." >&2
    exit $EXIT_ERR
fi

# Opcionalis tomorites kapcsolo felvetele
option=`echo $1 | sed -n "s/^-\+//p"`; if [ ! -z "$option" ]; then shift; fi
if [ "$option" = "c" -o "$option" = "compress" ]; then 
    compress="/bin/gzip"
else 
    compress="cat"
fi

# Kotelezo parameter a dump-olando adatbazis neve
database=${1?"$USAGE"};shift

# Kotelezo parameter a dump-olando tablak listaja
tablelist=${1?"$USAGE"};shift
tables=`cat $tablelist 2>/dev/null`
if [ -z "$tables" ]; then
    echo "No tables in $tablelist." >&2
    exit $EXIT_ERR
fi

# Opcionalis parameter a keszulo backup pathname
# Alapertelmezes az aktualis konyvtarban, egyedi nevvel
# Kiterjesztes igazitasa, ha tomorites elo van irva
# Ertelmezi a "-" pathname-et, ez esetben a stdout-ra ir.
filename=${1:-`pwd`/`hostname`.`date +%Y%m%d%H%M%S`.$database.`echo $tablelist | sed "s/\(.*\)\/\(.*\)$/\2/"`.sql}; shift
if [ "$filename" = "-" ]; then
    filename=""
else
    case "${compress##*/}" in
        "gzip")
	    filename="${filename%.gz}.gz"
	;;
    esac
fi

# Opcionalis parameter a keszulo backup birtokosa 
# Alapertelemezes a "backup" felhasznalo
dumpuser=${1:-"backup"}; shift

dumpfilerights="640"

mysql_dsm="/usr/bin/mysql --defaults-file=/etc/mysql/debian.cnf"
mysqldump_dsm="/usr/bin/mysqldump --defaults-file=/etc/mysql/debian.cnf"
dumpparameters="--tables --complete-insert --add-drop-table --extended-insert"

# Ellenorizzuk, hogy a megadott adatbazis letezik-e - ha nem, hibauzenettel vege
if [ -z "`$mysql_dsm --batch --execute='show databases;' | \
          sed s/^Database$// | \
	  sed -n s/^$database$/X/p`" ]; then
    echo "MySQL database \"$database\" isn't found." >&2
    exit $EXIT_ERR
fi

# Elozo backup torlese, ha szukseges, es maga a dump
if [ -f "$filename" ]; then rm $filename; fi
for table in $tables
do
    if [ ! -z "$filename" ]; then
	echo $database.$table
        $mysqldump_dsm $dumpparameters $database $table | $compress  >>$filename
    else
	$mysqldump_dsm $dumpparameters $database $table | $compress
    fi
done
if [ -f "$filename" ]; then  chown $dumpuser $filename; chmod $dumpfilerights $filename; fi

# Vege
